import { ActiveHashRecord, EagerQueryable } from "activehashie";
import { ModelValidationErrorReports } from "./model_validation_error_report";
/** validatesで利用できるメソッド名と引数の対応 */
export interface ValidatesMethods {
    presence: ValidatesMethod.Params.Presence;
    presenceBelongsTo: ValidatesMethod.Params.Presence;
    uniqueness: ValidatesMethod.Params.Uniqueness;
    length: ValidatesMethod.Params.Length;
    format: ValidatesMethod.Params.Format;
    numericality: ValidatesMethod.Params.Numericality;
    inclusion: ValidatesMethod.Params.Inclusion;
    exclusion: ValidatesMethod.Params.Exclusion;
}
export declare namespace ValidatesMethod {
    /** validatesで利用できるメソッド引数 */
    namespace Params {
        type Presence = true;
        type Uniqueness = true;
        interface Length {
            minimum?: number;
            maximum?: number;
            is?: number;
        }
        interface Format {
            with?: RegExp;
            without?: RegExp;
        }
        type Numericality = true | {
            only_integer?: boolean;
            greater_than?: number;
            greater_than_or_equal_to?: number;
            equal_to?: number;
            less_than?: number;
            less_than_or_equal_to?: number;
        };
        interface Inclusion {
            in: any[];
        }
        interface Exclusion {
            in: any[];
        }
    }
    /** validatesで利用できるメソッド */
    namespace Method {
        /** 存在チェック */
        function presence<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, _: ValidatesMethod.Params.Presence, model: EagerQueryable<Record>, column: keyof Record): void;
        /** 関連を考慮した存在チェック */
        function presenceBelongsTo<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, _: ValidatesMethod.Params.Presence, model: EagerQueryable<Record>, column: keyof Record): void;
        /** ユニーク性チェック */
        function uniqueness<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, _: ValidatesMethod.Params.Uniqueness, model: EagerQueryable<Record>, column: keyof Record): void;
        /** 長さチェック */
        function length<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Length, model: EagerQueryable<Record>, column: keyof Record): void;
        /** 文字列フォーマットチェック */
        function format<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Format, model: EagerQueryable<Record>, column: keyof Record): void;
        /** 数値チェック */
        function numericality<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Numericality, model: EagerQueryable<Record>, column: keyof Record): void;
        /** 範囲内チェック */
        function inclusion<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Inclusion, model: EagerQueryable<Record>, column: keyof Record): void;
        /** 範囲外チェック */
        function exclusion<Record extends ActiveHashRecord>(errors: ModelValidationErrorReports<Record>, params: ValidatesMethod.Params.Exclusion, model: EagerQueryable<Record>, column: keyof Record): void;
    }
}
